AddressBookError

Enum AddressBookError 

pub enum AddressBookError {
    PeerAlreadyConnected,
    PeerNotFound,
    PeersDataChanged(&'static str),
    PeerIsBanned,
    AddressBooksChannelClosed,
    AddressBookTaskExited,
}
Possible errors when dealing with the address book. This is boxed when returning an error in the [tower::Service].

Variants



PeerAlreadyConnected

The peer is already connected.



PeerNotFound

The peer is not in the address book for this zone.



PeersDataChanged(&'static str)

Immutable peer data was changed.



PeerIsBanned

The peer is banned.



AddressBooksChannelClosed

The channel to the address book has closed unexpectedly.



AddressBookTaskExited

The address book task has exited.